/*
    tsync - a utility to sync remote encrypted copies of a tstore
    Copyright (C) 2005  Kasper Dupont

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    with permission from the author any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    $Id: tsync-cat-record.c,v 1.6 2007/01/09 21:45:17 kasperd Exp $
*/

#include "tsync.h"

int main(int argc, char ** argv)
{
  uint32_t record_count;
  uint32_t record_number;
  int server_rfd,server_wfd;
  char *cookie =getenv("TSYNC_COOKIE");

  if (argc < 3) {
    fprintf(stderr,"Usage: %s <nr> <cmd>\n",argv[0]);
    return EXIT_FAILURE;
  }

  if (!cookie) {
    fprintf(stderr,"TSYNC_ variables missing in environment\n");
    return EXIT_FAILURE;
  }

  start_server(&server_rfd,&server_wfd,argv+2,&record_count);
  //fprintf(stderr,"%u\n",record_count);

  record_number=htonl(atoi(argv[1]));
  assert(write(server_wfd,"S",1)==1);
  assert(write(server_wfd,&record_number,4)==4);

  while(1) {
    uint32_t byte_count=htonl(~(uint32_t)0);
    assert(write(server_wfd,"R",1)==1);
    assert(write(server_wfd,&byte_count,4)==4);
    assert(read(server_rfd,&byte_count,4)==4);
    byte_count=ntohl(byte_count);
    if (byte_count == 0) return 0;
    while(byte_count) {
      uint8_t buffer[4096];
      int max_read=sizeof(buffer);
      int r;
      if (max_read>byte_count) max_read=byte_count;
      r=read(server_rfd,buffer,max_read);
      if (r<1) {
	perror("read");
	return EXIT_FAILURE;
      }
      assert(write(1,buffer,r)==r);
      byte_count-=r;
    }
  }
  return 0;
}
