/*
    tsync - a utility to sync remote encrypted copies of a tstore
    Copyright (C) 2005  Kasper Dupont

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    with permission from the author any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    $Id: tsync-put-pass.c,v 1.5 2007/01/09 21:45:17 kasperd Exp $
*/

#include "tsync.h"

#define BUFSIZE 3

int main(int argc, char ** argv)
{
  char *gpg_cmd[]={"gpg","--symmetric","--cipher-algo","AES256",NULL};
  uint32_t record_count;
  int server_rfd,server_wfd,gpg_rfd,gpg_wfd;
  char *cookie =getenv("TSYNC_COOKIE");
  char *pass   =getenv("TSYNC_PASS");
  char buf[BUFSIZE];
  int rl;
  int wrote_something=0;

  if (argc < 2) {
    fprintf(stderr,"Usage: %s <cmd>\n",argv[0]);
    return EXIT_FAILURE;
  }

  if (!(cookie && (strlen(cookie)==43) && pass)) {
    fprintf(stderr,"TSYNC_ variables missing in environment\n");
    return EXIT_FAILURE;
  }

  start_server(&server_rfd,&server_wfd,argv+1,&record_count);

  if (record_count != 0) {
    fprintf(stderr,"Record count %u expected 0\n",record_count);
    return EXIT_FAILURE;
  }


  start_helper(&gpg_rfd,&gpg_wfd,gpg_cmd);
  assert(write(gpg_wfd,pass,43)==43);
  close(gpg_wfd);

  assert(write(server_wfd,"L",1)==1);

  while ((rl=read(gpg_rfd,buf,BUFSIZE))>0) {
    uint32_t n_wl=htonl(rl);
    assert(write(server_wfd,"W",1)==1);
    assert(write(server_wfd,&n_wl,4)==4);
    assert(write(server_wfd,buf,rl)==rl);
    wrote_something=1;
  }

  if (rl<0) {
    perror("write");
    return EXIT_FAILURE;
  }

  if (!wrote_something) return EXIT_FAILURE;

  assert(write(server_wfd,"C",1)==1);

  assert((read(server_rfd,buf,1)==1)&&(buf[0]=='C'));

  return 0;
}
