/*
    tsync - a utility to sync remote encrypted copies of a tstore
    Copyright (C) 2005  Kasper Dupont

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    with permission from the author any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    $Id: tsync-size.c,v 1.2 2007/01/09 21:45:17 kasperd Exp $
*/

#include "tsync.h"
#include <sys/wait.h>

int main(int argc, char ** argv)
{
  char buffer[8];
  off_t seek_location;
  uint32_t record_count;
  int server_rfd,server_wfd;

  char *cookie =getenv("TSYNC_COOKIE");

  if (argc < 2) {
    fprintf(stderr,"Usage: %s <cmd>\n",argv[0]);
    return EXIT_FAILURE;
  }

  if (!cookie) {
    fprintf(stderr,"TSYNC_ variables missing in environment\n");
    return EXIT_FAILURE;
  }

  start_server(&server_rfd,&server_wfd,argv+1,&record_count);

  switch(record_count) {
  case 0:
    fprintf(stderr,"No records in encrypted storage, there should at least be an encrypted password\n");
    return EXIT_FAILURE;
  case 1:
    seek_location=512;
    break;
  default:
    {
      uint32_t vv=htonl(record_count-1);
      assert(write(server_wfd,"S",1)==1);
      assert(write(server_wfd,&vv,4)==4);
      vv=htonl(8);
      assert(write(server_wfd,"R",1)==1);
      assert(write(server_wfd,&vv,4)==4);
      assert(read(server_rfd,&vv,4)==4);
      assert(ntohl(vv)==8);
      assert(read(server_rfd,buffer,8)==8);
      seek_location=ntoh64((uint32_t*)buffer);
    }
  }

  printf("%lld\n",seek_location);

  return 0;
}
