/*
    tsync - a utility to sync remote encrypted copies of a tstore
    Copyright (C) 2005  Kasper Dupont

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    with permission from the author any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    $Id: tsync-sizes.c,v 1.2 2007/01/09 21:45:17 kasperd Exp $
*/

#include "tsync.h"

int main(int argc, char ** argv)
{
  uint32_t record_count,i;
  int server_rfd,server_wfd;
  char *cookie =getenv("TSYNC_COOKIE");

  if (argc < 2) {
    fprintf(stderr,"Usage: %s <cmd>\n",argv[0]);
    return EXIT_FAILURE;
  }

  if (!cookie) {
    fprintf(stderr,"TSYNC_ variables missing in environment\n");
    return EXIT_FAILURE;
  }

  start_server(&server_rfd,&server_wfd,argv+1,&record_count);

  for (i=record_count-1;i;--i) {
    uint32_t buf[2];
    uint32_t byte_count=htonl(8);
    uint32_t record_number=htonl(i);
    uint64_t size;
    assert(write(server_wfd,"S",1)==1);
    assert(write(server_wfd,&record_number,4)==4);
    assert(write(server_wfd,"R",1)==1);
    assert(write(server_wfd,&byte_count,4)==4);
    assert(read(server_rfd,&byte_count,4)==4);
    assert(ntohl(byte_count)==8);
    assert(read(server_rfd,buf,8)==8);
    size=ntoh64(buf);
    printf("%llu%s\n",size/512,(size%512)?"+":"");
  }

  return 0;
}
