/*
    tsync - a utility to sync remote encrypted copies of a tstore
    Copyright (C) 2005  Kasper Dupont

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    with permission from the author any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    $Id: tsync-util.c,v 1.6 2007/01/09 21:45:17 kasperd Exp $
*/

#include "tsync.h"

void start_helper(int *rfd, int *wfd, char ** cmd)
{
  int pipe_rfd[2],pipe_wfd[2];
  if (pipe(pipe_rfd)||pipe(pipe_wfd)) {
    perror("pipe");
    exit(EXIT_FAILURE);
  }
  switch(fork()) {
  case 0:
    dup2(pipe_wfd[0],0);
    dup2(pipe_rfd[1],1);
    close(pipe_rfd[0]);
    close(pipe_rfd[1]);
    close(pipe_wfd[0]);
    close(pipe_wfd[1]);
    execvp(cmd[0],cmd);
    perror(cmd[0]);
    _exit(EXIT_FAILURE);
  case -1:
    perror("fork");
    exit(EXIT_FAILURE);
  }
  close(pipe_rfd[1]);
  close(pipe_wfd[0]);
  fcntl(pipe_rfd[0],F_SETFD,1); /* close-on-exec */
  fcntl(pipe_wfd[1],F_SETFD,1); /* close-on-exec */
  *rfd=pipe_rfd[0];
  *wfd=pipe_wfd[1];
}

void start_server(int *rfd, int *wfd, char ** cmd, uint32_t *record_count)
{
  uint32_t rc;
  start_helper(rfd,wfd,cmd);
  assert(write(*wfd,getenv("TSYNC_COOKIE"),43)==43);
  assert(read(*rfd,&rc,4)==4);
  if (record_count) *record_count=ntohl(rc);
}

void start_gpg(int *rfd, int *wfd, char * pass, int encrypt)
{
  int l=strlen(pass);
  int pass_pipe[2];
  char fdbuf[42];
  char *gpg_cmd[]={"gpg","--symmetric","--no-tty","--cipher-algo","AES256","--passphrase-fd",fdbuf,NULL};
  assert(encrypt);
  if (pipe(pass_pipe)) {
    perror("pipe");
    exit(EXIT_FAILURE);
  }
  fcntl(pass_pipe[1],F_SETFD,1); /* close-on-exec */
  sprintf(fdbuf,"%d",pass_pipe[0]);
  start_helper(rfd,wfd,gpg_cmd);
  close(pass_pipe[0]);
  assert(write(pass_pipe[1],pass,l)==l);
  close(pass_pipe[1]);
}
